@@ -18,7 +18,7 @@
 //! ```
 //! And just errbang!
 //! ```no_run
-//! errbang!(err:BrokenHeader);
+//! errbang!(err::BrokenHeader);
 //! ```
 //! # More Examples
 //! ```no_run
@@ -35,6 +35,19 @@
 //!     Ok(())
 //! }
 //! ```
+//! Please use our Master Result<T> and ResultSend<T> instead std::result::Result or io::Result etc..
+//! ```no_run
+//! /// Master Result
+//! pub type Result<T> = result::Result<T, Box<dyn error::Error>>;
+//! /// Master Result for Send + Sync trait
+//! pub type ResultSend<T> = result::Result<T, Box<dyn error::Error + Send + Sync>>;
+//! ```
+
+//! ---
+//! ### just put this in your project.
+//! ```rust
+//! pub use utils_results::*;
+//! ```
 
 /// make some error. Master Result::Err()
 /// ```no_run
@@ -62,9 +75,26 @@ macro_rules! errbangsend {
     };
 }
 
+/// any type of inside Err() can be converted<br>
+/// and Ok() will be unwraped, converted err will be escaped
+/// ```no_run
+/// // <Unwraped Ok> = errcast!(<Any Result>, <Master Err>, <Optional,..>);
+/// let num_read = errcast!(file.read(&mut buf), err::ReadErr, "cannot read.");
+/// ```
+#[macro_export]
+macro_rules! errcast {
+    ($result:expr, $kind:ty$(, $i:expr)*) => {
+        match $result {
+            Ok(v) => v,
+            Err(_) => return errbang!($kind$(, $i)*),
+        }
+    };
+}
+
 /// any type of inside Err() can match this
 /// ```no_run
 /// if let Err(e) = some_result() {
+///     // errmatch!(<Unwraped Err>, <Any Type>)
 ///     if errmatch!(e, err::MyError0) {
 ///         // ...   
 ///     }
@@ -81,8 +111,8 @@ macro_rules! errmatch {
     };
 }
 
-/// matched error returns or excutes, other errors return to outside<br>
-/// and Ok(v) will unwrap and to be v
+/// matched error returns or excutes, other errors return to outside(escape)<br>
+/// and Ok() will unwrap
 ///```no_run
 /// fn main() -> Result<()> {
 ///     let num_read = errextract!(read(),
